@@ -1,16 +1,22 @@
-/*** analog 3.0      http://www.statslab.cam.ac.uk/~sret1/analog/  ***/
+/***             analog 4.1             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
+ *** stated otherwise. Distribution, usage and modification of this program is
+ *** subject to the conditions of the Licence which you should have received
+ *** with it. This program comes with no warranty, expressed or implied.   ***/
 
-/*** macinput.c; input functions for Mac, (c) Jason Linhart 1998 */
+/*** The contents of this file is copyright (c) Jason Linhart 1998. ***/
 
-#define REAL_STDIO				/* Define these to suppress defines in analhea2.h */
+/*** macinput.c; input functions for Mac */
 
-#include "analhea2.h"
+#define REAL_STDIO	/* Define these to suppress defines in anlghea3.h */
+
+#include "anlghea3.h"
 
 #ifdef MAC
 #ifdef USE_ZLIB
 #include <unix.h>
 #include <fcntl.h>
-#include "zlib.h"
+#include "my_zlib.h"
 #endif
 
 #ifdef LINE_PARSER
@@ -68,7 +74,7 @@ GotRequiredParams(AppleEvent *theAppleEvent)
 	return retErr;
 	}
 
-static pascal OSErr					/* Used for Open, Print, and Close events */
+static pascal OSErr					/* Used for Print and Close events */
 DoAENoop(AppleEvent *theAppleEvent,AppleEvent *reply,long handlerRefcon)
 {
 #pragma unused ( handlerRefcon )
@@ -137,6 +143,23 @@ DoAEDo(AppleEvent *theAppleEvent,AppleEvent *reply,long handlerRefcon)
   return(err);
 }
 
+int mac_quit_now = 0;
+
+static pascal OSErr                                     /* Used for Quit event 
+*/
+DoAEQuit(AppleEvent *theAppleEvent,AppleEvent *reply,long handlerRefcon)
+{
+#pragma unused ( handlerRefcon )
+        OSErr err;
+        
+        err=GotRequiredParams(theAppleEvent);
+        if (!err && reply->dataHandle)                          /*      a reply 
+is sought */
+                err=AEPutParamPtr(reply,'errs','TEXT',"Ignoring",8);
+        mac_quit_now=1;
+        return(err);
+}
+
 char TryAEOpen(void);
 
 char
@@ -163,7 +186,7 @@ TryAEOpen(void)
 		result=AEInstallEventHandler(kCoreEventClass,kAEPrintDocuments,HandlerUPP,0,false);
 		}
 	if (result==noErr)	{
-		HandlerUPP=NewAEEventHandlerProc(DoAENoop);
+		HandlerUPP=NewAEEventHandlerProc(DoAEQuit);
 		result=AEInstallEventHandler(kCoreEventClass,kAEQuitApplication,HandlerUPP,0,false);
 		}
         if (result==noErr)      {
@@ -246,7 +269,7 @@ mac_fopen(const char *name,const char *mode)
 #ifdef USE_ZLIB
         gzsetalloc(my_gz_alloc_func,my_gz_free_func,nil);
 #endif
-        if (!STRCMP(name,"%%%") && !STRCMP(mode,"r") && haveFSS) {
+        if (!strcmp(name,"%%%") && !strcmp(mode,"r") && haveFSS) {
 		if (!HOpenDF(myFSS.vRefNum,myFSS.parID,myFSS.name,fsRdPerm,&refNum)) {
 			if (in_fp) return(fdopen(refNum,"r"));
 #ifdef USE_ZLIB
@@ -345,8 +368,14 @@ mac_getc(FILE *file)
 	return(result);
 	}
 
+int
+mac_feof(FILE *file)
+{
+	if (in_fp!=(gzFile)file) return(feof(file));
+	return(buff_cnt<=0);
+	}
+
 #endif
 #endif
 
 /* END OF macinput.c - read input files */
-
