@@ -1,7 +1,12 @@
-/*** analog 3.0 ***/
-/* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
+/***             analog 4.1             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
+ *** stated otherwise. Distribution, usage and modification of this program is
+ *** subject to the conditions of the Licence which you should have received
+ *** with it. This program comes with no warranty, expressed or implied.   ***/
 
 /*** macstuff.c; stuff only required for the Mac port ***/
+/*** The contents of this file is copyright various authors as follows. ***/
+
 /* The functions in this file inside #ifdef MAC_EVENTS are due to, and
    copyright, Jason Linhart (jason@summary.net), 1996. */
 /* The functions in this file inside #ifdef MACDIRENT are due to
@@ -19,11 +24,12 @@
 */
 
 #define REAL_ALLOC
-#include "analhea2.h"
+#include "anlghea3.h"
 #ifdef MAC_EVENTS
 
 static char *cmd_vect[64] = {
 	"analog",
+	"-G",
 	"+g%%%",
 	0
 	};
@@ -60,10 +66,14 @@ void MacInit(int *argc,char **argv[])
 
   SIOUXSettings.asktosaveonclose=false;
   (void)printf("Processing...\n");
+  setvbuf(stdout,NULL,_IOLBF,BUFSIZ);
   if ((c=TryAEOpen())!=0) {
-  	*argc=2;
-  	if (c!='#') cmd_vect[1]=cmd_vect[1]+2;
-  	}
+    if (c!='#') {
+      cmd_vect[1]="%%%";
+      *argc=2;
+    }
+    else *argc=3;
+  }
   else if (mac_do_script[0]) 
         *argc=1+CmdParse(cmd_vect+1,mac_do_script,63);
   else *argc=1;
@@ -85,8 +95,11 @@ void MacFini(void)
   mac_temp_free();
 }
 
+extern int mac_quit_now;
+
 void MacIdle(void)
 {
+  extern logical anywarns;
   static long time = 0;
 
   EventRecord myEvent;
@@ -94,6 +107,10 @@ void MacIdle(void)
   char theChar;
 
   if (TickCount()<time) return;
+  if (mac_quit_now) {
+    anywarns = FALSE;  /* kludge so that window doesn't sit around */
+    my_exit(1);
+  }
   SystemTask();
   if (WaitNextEvent(everyEvent, &myEvent, 1, nil)) {
 
@@ -345,11 +362,11 @@ int IpAddr2Name(char *hostname)
     lHostAddr=0;
     cptr=hostname;
     for (cnt=0; cnt<4; ++cnt) {
-      if (!isdigit(*cptr)) return(0);
+      if (!ISDIGIT(*cptr)) return(0);
       tmp=atoi(cptr);
       if (tmp<0 || tmp>255) return(0);
       lHostAddr=(lHostAddr<<8)|tmp;
-      while (isdigit(*cptr)) ++cptr;
+      while (ISDIGIT(*cptr)) ++cptr;
       if (cnt!=3 && *cptr!='.') return(0);
       ++cptr;
     }
@@ -543,6 +560,8 @@ my_temp_malloc(size_t size)
 	return((void *)ret_ptr);
 	}
 
+#define MAC_LEAVE_FREE          (64*1024)
+
 static void *
 sub_mac_malloc(size_t size)
 {
@@ -550,11 +569,11 @@ sub_mac_malloc(size_t size)
 
 	size=(size+3)&~3;
 	if (size>=MY_BIG_SIZE) {
-		if (MaxBlock()<16*1024+size) return(my_temp_malloc(size));
+		if (MaxBlock()<=MAC_LEAVE_FREE+size) return(my_temp_malloc(size));
 		return(malloc(size));
 		}
 	if (size>my_cur_avail) {
-		if (MaxBlock()<16*1024+MY_BLOCK_SIZE) return(my_temp_malloc(size));
+		if (MaxBlock()<MAC_LEAVE_FREE+MY_BLOCK_SIZE) return(my_temp_malloc(size));
 		my_cur_block=malloc(MY_BLOCK_SIZE);
 		my_cur_avail=MY_BLOCK_SIZE;
 		}
@@ -630,4 +649,3 @@ mac_free(void *ptr)
 		}
 	}
 #endif
-
