@@ -1,9 +1,12 @@
-/*** analog 3.0 ***/
-/* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
+/***             analog 4.1             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
+ *** stated otherwise. Distribution, usage and modification of this program is
+ *** subject to the conditions of the Licence which you should have received
+ *** with it. This program comes with no warranty, expressed or implied.   ***/
 
 /*** win32.c; stuff only required for the Win32 port ***/
 /* This stuff is due to Magnus Hagander (mha@edu.sollentuna.se) */
-#include "analhea2.h"
+#include "anlghea3.h"
 #ifdef WIN32
 
 /*
